Package: ASSISTant
Type: Package
Title: Adaptive Subgroup Selection in Group Sequential Trials
Version: 1.4.3
Date: 2022-11-30
VignetteBuilder: knitr
Authors@R: c(person("Tze Leung", "Lai", role=c("ctb"),
	   	    email = "lait@stanford.edu"),
	     person("Philip", "Lavori", role=c("aut"),
	   	    email = "lavori@stanford.edu"),
	     person("Olivia", "Liao", role=c("aut"),
	   	    email = "oliao@onyx.com"),
  	     person("Balasubramanian", "Narasimhan", role=c("aut", "cre"),
	   	    email = "naras@stat.Stanford.EDU"),
             person("Ka Wai", "Tsang", role=c("aut"),
	   	    email = "ktsang@stanford.edu"))
URL: https://github.com/bnaras/ASSISTant
BugReports: https://github.com/bnaras/ASSISTant/issues
Description: Clinical trial design for subgroup selection in three-stage group
             sequential trial as described in Lai, Lavori and Liao (2014,
	     <doi:10.1016/j.cct.2014.09.001>). Includes facilities for design,
	     exploration and analysis of such trials. An implementation of
	     the initial DEFUSE-3 trial is also provided as a vignette.
License: GPL (>= 2)
Encoding: UTF-8
RoxygenNote: 7.2.2
Imports: R6, mvtnorm, knitr, magrittr, dplyr
Suggests: rmarkdown
NeedsCompilation: no
Packaged: 2022-12-01 14:56:45 UTC; naras
Author: Tze Leung Lai [ctb],
  Philip Lavori [aut],
  Olivia Liao [aut],
  Balasubramanian Narasimhan [aut, cre],
  Ka Wai Tsang [aut]
Maintainer: Balasubramanian Narasimhan <naras@stat.Stanford.EDU>
Repository: CRAN
Date/Publication: 2022-12-02 09:30:09 UTC
Built: R 4.6.0; ; 2026-04-26 11:35:10 UTC; unix
