# Generated by roxygen2: do not edit by hand

export(ASSISTDesign)
export(ASSISTDesignB)
export(ASSISTDesignC)
export(DEFUSE3Design)
export(colNamesForStage)
export(computeMHPBoundaries)
export(computeMHPBoundaryITT)
export(computeMeanAndSD)
export(generateDiscreteData)
export(generateNormalData)
export(groupSampleSize)
export(mHP.b)
export(mHP.btilde)
export(mHP.c)
export(wilcoxon)
importFrom(R6,R6Class)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,select)
importFrom(dplyr,summarize)
importFrom(dplyr,ungroup)
importFrom(knitr,kable)
importFrom(magrittr,"%>%")
importFrom(mvtnorm,Miwa)
importFrom(mvtnorm,pmvnorm)
importFrom(stats,dnorm)
importFrom(stats,integrate)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,rnorm)
importFrom(stats,uniroot)
importFrom(stats,wilcox.test)
