
<!-- README.md is generated from the source: README.Rmd -->
ASSISTant
=========

[![Travis-CI Build Status](https://travis-ci.org/bnaras/ASSISTant.svg?branch=master)](https://travis-ci.org/bnaras/ASSISTant) [![CRAN\_Status\_Badge](http://www.r-pkg.org/badges/version/ASSISTant)](https://cran.r-project.org/package=ASSISTant) [![](https://cranlogs.r-pkg.org/badges/ASSISTant)](https://CRAN.R-project.org/package=ASSISTant)

`ASSISTant` is a package to assist in performing **A**daptive **S**ubgroup **S**election **I**n **S**equential **T**rials.

`ASSISTant` provides a three-stage adaptive group sequential clinical trial design with provision for selecting a subgroup where the treatment may be effective. The package provides facilities for design, exploration and analysis of such trials using either continuous or discrete outcomes. A complete implementation of the initial design for the DEFUSE-3 trial is also provided as a vignette.
