# tests/

Integration tests for the `assistant` crate.

## Responsibility Table

| File | Responsibility |
|------|----------------|
| `cli_sanity.rs` | Compile and link sanity check for the `clt` binary against all Layer 2 crates |
